module Rubinius
  BUILD_CONFIG = {
    :which_ruby     => :ruby,
    :build_ruby     => "/usr/local/bin/ruby18",
    :build_rake     => "/usr/local/bin/rake18",
    :build_perl     => "perl",
    :llvm           => :no,
    :llvm_configure => "",
    :cc             => "cc",
    :cxx            => "g++",
    :user_cflags    => "-O2 -pipe",
    :user_cppflags  => "-DOPENSSL_NO_STATIC_ENGINE -I/usr/local/include",
    :user_ldflags   => "-L/usr/local/lib",
    :defines        => ["HAS_READLINE"],
    :curses         => "curses",
    :host           => "alpha-unknown-openbsd5.3",
    :cpu            => "alpha",
    :vendor         => "unknown",
    :os             => "openbsd",
    :little_endian  => true,
    :sizeof_long    => 8,
    :bindir         => "/usr/local/lib/rubinius/bin",
    :libdir         => "/usr/local/lib/rubinius",
    :runtime        => "/usr/local/lib/rubinius/runtime",
    :kernel_path    => "/usr/local/lib/rubinius/kernel",
    :lib_path       => "/usr/local/lib/rubinius/lib",
    :ext_path       => "/usr/local/lib/rubinius/lib/ext",
    :includedir     => "/usr/local/lib/rubinius/include",
    :mandir         => "/usr/local/lib/rubinius/man",
    :gemsdir        => "/usr/local/lib/rubinius/gems",
    :sitedir        => "/usr/local/lib/rubinius/site",
    :vendordir      => "/usr/local/lib/rubinius/vendor",
    :program_name   => "rbx",
    :version        => "1.2.4",
    :libversion     => "1.2",
    :release_date   => "2011-07-05",
    :config_version => 38
  }
end
